==> haskell-time-manager-0.0.1-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-manager
version:              0.0.1
visibility:           public
id:                   time-manager-0.0.1-5TJN3lcgzYxQLHgevAkfD
key:                  time-manager-0.0.1-5TJN3lcgzYxQLHgevAkfD
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Michael Snoyman and Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Scalable timer
description:          Scalable timer functions provided by a timer manager.
category:             System
abi:                  4eb7706dbb1a9b31d61786268226cf18
exposed:              True
exposed-modules:      System.TimeManager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/time-manager-0.0.1
hs-libraries:         HStime-manager-0.0.1-5TJN3lcgzYxQLHgevAkfD
depends:
    auto-update-0.1.6-5YcQmNPei3VAkx9JIA7w6z base-4.17.2.1
    unliftio-0.2.25.1-KNqQlHOV1yC27z4clRFnX2

haddock-interfaces:
    /usr/share/doc/haskell-time-manager/html/time-manager.haddock

haddock-html:         /usr/share/doc/haskell-time-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-manager-0.0.1-140-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-manager
version:              0.0.1
visibility:           public
id:                   time-manager-0.0.1-FsysWbyjQ4xGXs5jdFomJA
key:                  time-manager-0.0.1-FsysWbyjQ4xGXs5jdFomJA
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Michael Snoyman and Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Scalable timer
description:          Scalable timer functions provided by a timer manager.
category:             System
abi:                  b2f137dae90fc0fe16f087c2af342a97
exposed:              True
exposed-modules:      System.TimeManager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/time-manager-0.0.1
hs-libraries:         HStime-manager-0.0.1-FsysWbyjQ4xGXs5jdFomJA
depends:
    auto-update-0.1.6-1T9hY7rWbILKWtQfPwkC4S base-4.17.2.1
    unliftio-0.2.25.1-2icaVFExB3i9p5Bi6oB2UY

haddock-interfaces:
    /usr/share/doc/haskell-time-manager/html/time-manager.haddock

haddock-html:         /usr/share/doc/haskell-time-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
